==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/communication/kotlin/inputs/GetCommunicationServicePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.communication.kotlin.inputs

import com.pulumi.azurenative.communication.inputs.GetCommunicationServicePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property communicationServiceName The name of the CommunicationService resource.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetCommunicationServicePlainArgs(
    public val communicationServiceName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.communication.inputs.GetCommunicationServicePlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.communication.inputs.GetCommunicationServicePlainArgs =
        com.pulumi.azurenative.communication.inputs.GetCommunicationServicePlainArgs.builder()
            .communicationServiceName(communicationServiceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetCommunicationServicePlainArgs].
 */
@PulumiTagMarker
public class GetCommunicationServicePlainArgsBuilder internal constructor() {
    private var communicationServiceName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the CommunicationService resource.
     */
    @JvmName("vkvdjxvchfnbugcv")
    public suspend fun communicationServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.communicationServiceName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("rpyqtgqrxtsiuyxj")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetCommunicationServicePlainArgs = GetCommunicationServicePlainArgs(
        communicationServiceName = communicationServiceName ?: throw
            PulumiNullFieldException("communicationServiceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/communication/kotlin/inputs/GetCommunicationServicePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.communication.kotlin.inputs

import com.pulumi.azurenative.communication.inputs.GetCommunicationServicePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property communicationServiceName The name of the CommunicationService resource.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetCommunicationServicePlainArgs(
    public val communicationServiceName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.communication.inputs.GetCommunicationServicePlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.communication.inputs.GetCommunicationServicePlainArgs =
        com.pulumi.azurenative.communication.inputs.GetCommunicationServicePlainArgs.builder()
            .communicationServiceName(communicationServiceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetCommunicationServicePlainArgs].
 */
@PulumiTagMarker
public class GetCommunicationServicePlainArgsBuilder internal constructor() {
    private var communicationServiceName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the CommunicationService resource.
     */
    @JvmName("guqefxxynudyxggx")
    public suspend fun communicationServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.communicationServiceName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("dvejrrsnokgbribk")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetCommunicationServicePlainArgs = GetCommunicationServicePlainArgs(
        communicationServiceName = communicationServiceName ?: throw
            PulumiNullFieldException("communicationServiceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
